@@ -28,7 +28,9 @@ class MyForm(QtGui.QMainWindow):
                         "Free":"/opt/Simpsons/sounds/i.wav", "Crap":"/opt/Simpsons/sounds/j.wav",
 			   "Mr Burns":"/opt/Simpsons/sounds/k.wav", "Smart":"/opt/Simpsons/sounds/l.wav",
                         "OhCrap":"/opt/Simpsons/sounds/m.wav", "Whisky":"/opt/Simpsons/sounds/n.wav", 
-                        "WooHo":"/opt/Simpsons/sounds/o.wav"
+                        "WooHo":"/opt/Simpsons/sounds/o.wav", "Doh":"/opt/Simpsons/sounds/p.wav",
+                        "Brain":"/opt/Simpsons/sounds/q.wav", "Donuts":"/opt/Simpsons/sounds/r.wav",
+                        "Mail Here":"/opt/Simpsons/sounds/s.wav"
                         }
                 
         def playFart(self):
